@@ -13,9 +13,6 @@
 #include <KCrash>
 #include <KDBusService>
 #include <KLocalizedString>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 
 // Bomber
 #include "bomber.h"
@@ -23,17 +20,8 @@
 
 int main(int argc, char ** argv)
 {
-    // Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication app(argc, argv);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("bomber"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("bomberrc"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("bomberui.rc"));
-    migrate.migrate();
-#endif
+
     KLocalizedString::setApplicationDomain("bomber");
 
     KAboutData about(QStringLiteral("bomber"), i18n("Bomber"),
@@ -46,12 +34,15 @@ int main(int argc, char ** argv)
                     QStringLiteral("jp@stanwood.org.uk"));
     about.addAuthor(i18n("Mehmet Emre"), i18n("Porting to QGraphicsView."),
                     QStringLiteral("maemre2@gmail.com"));
-    QCommandLineParser parser;
     KAboutData::setApplicationData(about);
+
     KCrash::initialize();
+
+    QCommandLineParser parser;
     about.setupCommandLine(&parser);
     parser.process(app);
     about.processCommandLine(&parser);
+
     KDBusService service;
 
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("bomber")));
